<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <location filename="../about.ui" line="25"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM-Qt&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../about.ui" line="48"/>
        <source>Lightweight file manager</source>
        <translation>轻量级文件管理器</translation>
    </message>
    <message>
        <location filename="../about.ui" line="122"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</source>
        <translation>程序编写:
* 洪任谕 (PCMan) &lt;pcman.tw@gmail.com&gt;
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="144"/>
        <source>PCManFM-Qt File Manager

Copyright (C) 2009 - 2014 洪任諭 (Hong Jen Yee)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation>PCManFM-Qt 文件管理器

Copyright (C) 2009 - 2014 洪任谕 (Hong Jen Yee)

本程序是自由软件；您可以根据 GNU 通用公共许可证的条款重新发布它和（或）修改它。
在自由软件基金会发布的 GNU 通用公共许可证的条款下对其进行修改。
您可以根据自由软件基金会发布的 GNU 通用公共许可证（或许可证的第2版，或自行选择任何后来的版本）的条款重新发布和（或）修改它。

本程序的发布是希望它能起到作用。
但没有任何保证；甚至没有隐含的保证。
本程序的分发是希望它是有用的，但没有任何保证，甚至没有隐含的适销性或适用于某一特定目的的保证。 请参阅 GNU 通用公共许可证了解更多细节。

您应该已经收到了一份 GNU 通用公共许可证的副本。
如果没有，请写信给自由软件基金会，地址：51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA。</translation>
    </message>
    <message>
        <location filename="../about.ui" line="113"/>
        <source>Authors</source>
        <translation>作者</translation>
    </message>
    <message>
        <location filename="../about.ui" line="58"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/pcmanfm-qt&quot;&gt;https://github.com/lxqt/pcmanfm-qt&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/pcmanfm-qt&quot;&gt;https://github.com/lxqt/pcmanfm-qt&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="74"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Wiki: &lt;a href=&quot;https://github.com/lxqt/pcmanfm-qt/wiki&quot;&gt;https://github.com/lxqt/pcmanfm-qt/wiki&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Wiki: &lt;a href=&quot;https://github.com/lxqt/pcmanfm-qt/wiki&quot;&gt;https://github.com/lxqt/pcmanfm-qt/wiki&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="135"/>
        <source>License</source>
        <translation>许可</translation>
    </message>
</context>
<context>
    <name>AutoRunDialog</name>
    <message>
        <location filename="../autorun.ui" line="14"/>
        <source>Removable medium is inserted</source>
        <translation>已插入可移动媒体</translation>
    </message>
    <message>
        <location filename="../autorun.ui" line="33"/>
        <source>&lt;b&gt;Removable medium is inserted&lt;/b&gt;</source>
        <translation>&lt;b&gt;已插入可移动媒体&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../autorun.ui" line="40"/>
        <source>Type of medium:</source>
        <translation>媒体种类:</translation>
    </message>
    <message>
        <location filename="../autorun.ui" line="47"/>
        <source>Detecting...</source>
        <translation>正在检测...</translation>
    </message>
    <message>
        <location filename="../autorun.ui" line="56"/>
        <source>Please select the action you want to perform:</source>
        <translation>请选择您想执行的动作:</translation>
    </message>
</context>
<context>
    <name>BulkRenameDialog</name>
    <message>
        <location filename="../bulk-rename.ui" line="6"/>
        <source>Bulk Rename</source>
        <translation>批量重命名</translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="12"/>
        <source>Serial Renaming</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="36"/>
        <source># will be replaced by numbers starting with:</source>
        <translation># 会被替换为数字开始自:</translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="68"/>
        <source>Pad numbers with zero if possible</source>
        <translation>需要时补零</translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="75"/>
        <source>Use localized numbers</source>
        <translation>使用本地风格数字</translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="85"/>
        <source>Replacement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="97"/>
        <source>Find in names:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="107"/>
        <source>Replace with:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="117"/>
        <source>Case-sensitive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="124"/>
        <source>Regular expression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="134"/>
        <source>Change Case</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="146"/>
        <source>To upper case</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="156"/>
        <source>To lower case</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="27"/>
        <source>Name#</source>
        <translation>名称#</translation>
    </message>
</context>
<context>
    <name>ConnectServerDialog</name>
    <message>
        <location filename="../connect.ui" line="14"/>
        <source>Connect to remote server</source>
        <translation>连接至远程服务器</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="80"/>
        <source>Anonymous &amp;login</source>
        <translation>匿名登录(&amp;L)</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="90"/>
        <source>Login as &amp;user:</source>
        <translation>作为用户连接(&amp;S):</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="29"/>
        <source>Specify remote folder to connect</source>
        <translation>指定要连接的远程目录</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="36"/>
        <source>Type:</source>
        <translation>种类:</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="56"/>
        <source>Port:</source>
        <translation>端口:</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="70"/>
        <source>Path:</source>
        <translation>路径:</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="46"/>
        <source>Host:</source>
        <translation>主机:</translation>
    </message>
</context>
<context>
    <name>DesktopEntryDialog</name>
    <message>
        <location filename="../desktopentrydialog.ui" line="14"/>
        <source>Create Launcher</source>
        <translation>创建启动器</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="38"/>
        <source>Name:</source>
        <translation>名称:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="45"/>
        <source>Specific name of this launcher.</source>
        <translation>该启动器的名称.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="58"/>
        <source>Description:</source>
        <translation>描述：</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="65"/>
        <source>A short description or generic name, like &quot;Web Browser&quot; or &quot;Home Directory&quot;.

It can be left empty.</source>
        <translation>简短的描述，如“网络浏览器”或“家目录”.

可以留空.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="77"/>
        <source>Comment:</source>
        <translation>注释 :</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="84"/>
        <source>A short comment.

It can be left empty.</source>
        <translation>简短的注释.

可以留空.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="117"/>
        <source>Command:</source>
        <translation>命令：</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="133"/>
        <location filename="../desktopentrydialog.ui" line="164"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="142"/>
        <source>Icon:</source>
        <translation>图标：</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="151"/>
        <source>Icon to display in file manager, menus, etc.</source>
        <translation>在文件管理器、菜单等处显示的图标.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="173"/>
        <location filename="../desktopentrydialog.ui" line="183"/>
        <source>Run in terminal?</source>
        <translation>在终端运行？</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="176"/>
        <source>Terminal:</source>
        <translation>终端:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="186"/>
        <source>Whether the launched program should run in a terminal window.</source>
        <translation>是否在终端中运行该程序.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="190"/>
        <source>No</source>
        <translation>否</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="195"/>
        <source>Yes</source>
        <translation>是</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="203"/>
        <source>Type:</source>
        <translation>类型:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="210"/>
        <source>Whether this is a link or executes a command.</source>
        <translation>这是链接还是命令.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="214"/>
        <source>Application</source>
        <translation>应用程序</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="219"/>
        <source>Link</source>
        <translation>链接</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="96"/>
        <source>Categories:</source>
        <translation>分类:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="103"/>
        <source>Semicolon separated categories in which the entry should be shown if it is used by the DE&apos;s main menu (e.g., when put inside ~/.local/share/applications).

It is needed only when you want to use the created file in the main menu. Otherwise, you could leave it empty.

Examples: AudioVideo, Audio, Video, Development, Education, Game, Graphics, Network, Office, Settings, System, Utility, Qt.</source>
        <translation>使用逗号分隔的分类.当被用于桌面环境的应用程序菜单时(如被放在~/.local/share/applications/)，将由此决定该启动器图标所在的位置.

只有当您在为应用程序菜单创建启动器时才需要填写此项，否则可以为空.

比如:AudioVideo, Audio, Video, Development, Education, Game, Graphics, Network, Office, Settings, System, Utility, Qt.</translation>
    </message>
</context>
<context>
    <name>DesktopFolder</name>
    <message>
        <location filename="../desktop-folder.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="23"/>
        <source>Desktop</source>
        <translation>桌面</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="29"/>
        <source>Desktop folder:</source>
        <translation>桌面文件夹:</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="36"/>
        <source>Image file</source>
        <translation>图像文件</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="42"/>
        <source>Folder path</source>
        <translation>文件夹路径</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="49"/>
        <source>&amp;Browse</source>
        <translation>浏览(&amp;B)</translation>
    </message>
</context>
<context>
    <name>DesktopPreferencesDialog</name>
    <message>
        <location filename="../desktop-preferences.ui" line="14"/>
        <source>Desktop Preferences</source>
        <translation>桌面偏好设置</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="338"/>
        <location filename="../desktop-preferences.ui" line="344"/>
        <source>Background</source>
        <translation>背景</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="385"/>
        <source>Wallpaper mode:</source>
        <translation>墙纸模式:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="408"/>
        <source>Wallpaper image file:</source>
        <translation>墙纸图像文件:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="350"/>
        <source>Select background color:</source>
        <translation>选择背景颜色:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="417"/>
        <source>Image file</source>
        <translation>图像文件</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="423"/>
        <source>Image file path</source>
        <translation>图像文件路径</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="430"/>
        <source>&amp;Browse</source>
        <translation>浏览(&amp;B)</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="30"/>
        <source>Icons</source>
        <translation>图标</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="36"/>
        <source>Icon size:</source>
        <translation>图标大小:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="49"/>
        <source>Label Text</source>
        <translation>标签文字</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="113"/>
        <source>Select shadow color:</source>
        <translation>选择阴影颜色:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="61"/>
        <source>Select font:</source>
        <translation>选择字体:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="24"/>
        <source>General</source>
        <translation>常规</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="87"/>
        <source>Select text color:</source>
        <translation>选择文本颜色：</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="136"/>
        <source>Spacing</source>
        <translation>间距</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="145"/>
        <source>Minimum item margins:</source>
        <translation>最小项目外边距:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="152"/>
        <source>3 px by default.</source>
        <translation>默认为3px。</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="155"/>
        <location filename="../desktop-preferences.ui" line="179"/>
        <location filename="../desktop-preferences.ui" line="237"/>
        <location filename="../desktop-preferences.ui" line="249"/>
        <location filename="../desktop-preferences.ui" line="275"/>
        <location filename="../desktop-preferences.ui" line="287"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="168"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="175"/>
        <source>1 px by default.
A space is also reserved for 3 lines of text.</source>
        <translation>默认为1px。
会保留三行文字高度的空间。</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="192"/>
        <source>Lock</source>
        <translation>锁定</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="230"/>
        <source>Margins of work area:</source>
        <translation>工作区边距:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="303"/>
        <source>By default, desktop folders will be opened in PCManFM-Qt if they
are left clicked, even when it is not the default file manager.</source>
        <translation>默认情况下，桌面文件夹被左键点击时会在 PCManFM-Qt 中打开，
即使它不是默认的文件管理器。</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="307"/>
        <source>Open desktop folders in default file manager by left clicking</source>
        <translation>在默认的文件管理器中打开桌面文件夹（左键点击时）</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="314"/>
        <source>Make all items stick to their positions</source>
        <translation>使所有项目都保持在自己的位置</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="373"/>
        <source>Wallpaper</source>
        <translation>壁纸</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="439"/>
        <source>Transform image based on EXIF data</source>
        <translation>基于 EXIF 数据转换图像</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="446"/>
        <source>Individual wallpaper for each monitor</source>
        <translation>为每个显示器设置各自的壁纸</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="473"/>
        <source>Slide Show</source>
        <translation>幻灯片放映</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="479"/>
        <source>Enable Slide Show</source>
        <translation>启用幻灯片播放</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="491"/>
        <source>Wallpaper image folder:</source>
        <translation>墙纸图像文件夹:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="505"/>
        <source>Browse</source>
        <translation>浏览</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="512"/>
        <source> hour(s)</source>
        <translation> 小时</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="522"/>
        <source>and</source>
        <translation>又</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="535"/>
        <source>Intervals less than 5min will be ignored</source>
        <translation>少于5分钟的间隔将被忽略</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="538"/>
        <source>Interval:</source>
        <translation>间隔:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="545"/>
        <source> minute(s)</source>
        <translation> 分钟</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="498"/>
        <source>Wallpaper folder</source>
        <translation>墙纸文件夹</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="587"/>
        <source>Randomize the slide show</source>
        <translation>随机幻灯片放映</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="620"/>
        <source>Visible Shortcuts</source>
        <translation>可见的快捷键</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="626"/>
        <source>Home</source>
        <translation>主目录</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="637"/>
        <source>Trash</source>
        <translation>回收站</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="648"/>
        <source>Computer</source>
        <translation>计算机</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="659"/>
        <source>Network</source>
        <translation>网络</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="614"/>
        <source>Advanced</source>
        <translation>高级</translation>
    </message>
</context>
<context>
    <name>HiddenShortcutsDialog</name>
    <message>
        <location filename="../shortcuts.ui" line="14"/>
        <source>Hidden Shortcuts</source>
        <translation>隐藏的快捷方式</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="21"/>
        <source>Shortcut</source>
        <translation>快捷方式</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="26"/>
        <source>Action</source>
        <translation>动作</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="31"/>
        <source>Esc</source>
        <translation>退出</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="34"/>
        <source>Focus view, clear filter bar</source>
        <translation>选中视图，清除筛选栏</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="39"/>
        <source>Ctrl+Esc</source>
        <translation>Ctrl+Esc</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="42"/>
        <source>Focus side-pane</source>
        <translation>选中侧边栏</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="47"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="50"/>
        <location filename="../shortcuts.ui" line="58"/>
        <source>Focus path entry</source>
        <translation>选中路径条</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="55"/>
        <source>Alt+D</source>
        <translation>Alt+D</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="63"/>
        <source>Ctrl+Tab</source>
        <translation>Ctrl+Tab</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="66"/>
        <location filename="../shortcuts.ui" line="82"/>
        <source>Next tab</source>
        <translation>下一个标签页</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="71"/>
        <source>Ctrl+Shift+Tab</source>
        <translation>Ctrl+Shift+Tab</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="74"/>
        <location filename="../shortcuts.ui" line="90"/>
        <source>Previous tab</source>
        <translation>上一个标签页</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="79"/>
        <source>Ctrl+PageDown</source>
        <translation>Ctrl+PageDown</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="87"/>
        <source>Ctrl+PageUp</source>
        <translation>Ctrl+PageUp</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="95"/>
        <source>Ctrl+Number</source>
        <translation>Ctrl+数字</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="98"/>
        <location filename="../shortcuts.ui" line="106"/>
        <source>Jump to tab</source>
        <translation>跳转到标签页</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="103"/>
        <source>Alt+Number</source>
        <translation>Alt+数字</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="111"/>
        <source>Backspace</source>
        <translation>后退</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="114"/>
        <source>Go up</source>
        <translation>向上</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="119"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="122"/>
        <source>Search dialog</source>
        <translation>搜索对话</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="127"/>
        <source>Shift+Insert</source>
        <translation>Shift+Insert</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="130"/>
        <source>Paste into transient filter bar</source>
        <translation>粘贴到临时的过滤栏</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="135"/>
        <source>Drop+Shift</source>
        <translation>按住 Shift 拖动</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="143"/>
        <source>Drop+Ctrl</source>
        <translation>按住 Ctrl 拖动</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="151"/>
        <source>Drop+Shift+Ctrl</source>
        <translation>按住 Shift+Ctrl 拖动</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="138"/>
        <source>Move file on dropping</source>
        <translation>拖放时移动文件</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="146"/>
        <source>Copy file on dropping</source>
        <translation>拖放时复制文件</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="154"/>
        <source>Make a symlink on dropping</source>
        <translation>拖放时创建一个软链接</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main-win.ui" line="14"/>
        <source>File Manager</source>
        <translation>文件管理器</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="81"/>
        <source>Recent F&amp;iles</source>
        <translation>最近的文件(&amp;F)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="143"/>
        <source>&amp;Toolbars</source>
        <translation>工具栏(&amp;T)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="150"/>
        <source>Path &amp;Bar</source>
        <translation>路径工具栏(&amp;B)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="157"/>
        <source>&amp;Filtering</source>
        <translation>过滤(&amp;F)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="232"/>
        <source>&amp;Tools</source>
        <translation>工具(&amp;T)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="291"/>
        <source>Go &amp;Up</source>
        <translation>向上(&amp;U)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="294"/>
        <source>Go Up</source>
        <translation>向上</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="297"/>
        <source>Alt+Up</source>
        <translation>Alt+Up</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="306"/>
        <source>&amp;Home</source>
        <translation>主文件夹(&amp;H)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="309"/>
        <source>Alt+Home</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="318"/>
        <source>&amp;Reload</source>
        <translation>重新载入(&amp;R)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="321"/>
        <source>F5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="330"/>
        <source>Go</source>
        <translation>转到</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="339"/>
        <source>Quit</source>
        <translation>退出</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="348"/>
        <source>&amp;About</source>
        <translation>关于(&amp;A)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="357"/>
        <source>&amp;New Window</source>
        <translation>新建窗口(&amp;N)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="360"/>
        <source>New Window</source>
        <translation>新建窗口</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="363"/>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="371"/>
        <source>Show &amp;Hidden</source>
        <translation>显示隐藏文件(&amp;H)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="374"/>
        <source>Ctrl+H</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="383"/>
        <source>&amp;Computer</source>
        <translation>计算机(&amp;C)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="392"/>
        <source>&amp;Trash</source>
        <translation>回收站(&amp;T)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="397"/>
        <source>&amp;Network</source>
        <translation>网络(&amp;N)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="406"/>
        <source>&amp;Desktop</source>
        <translation>桌面(&amp;D)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="415"/>
        <source>&amp;Add to Bookmarks</source>
        <translation>添加至书签(&amp;A)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="420"/>
        <source>&amp;Applications</source>
        <translation>应用程序(&amp;A)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="425"/>
        <source>Reload</source>
        <translation>刷新</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="433"/>
        <source>&amp;Icon View</source>
        <translation>图标视图(&amp;I)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="441"/>
        <source>&amp;Compact View</source>
        <translation>列表视图(&amp;C)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="449"/>
        <source>&amp;Detailed List</source>
        <translation>详细信息(&amp;D)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="457"/>
        <source>&amp;Thumbnail View</source>
        <translation>缩略图视图(&amp;T)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="466"/>
        <source>Cu&amp;t</source>
        <translation>剪切(&amp;T)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="469"/>
        <source>Ctrl+X</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="478"/>
        <source>&amp;Copy</source>
        <translation>复制 (&amp;C)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="481"/>
        <source>Ctrl+C</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="490"/>
        <source>&amp;Paste</source>
        <translation>粘贴(&amp;P)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="493"/>
        <source>Ctrl+V</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="502"/>
        <source>Select &amp;All</source>
        <translation>全选(&amp;A)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="505"/>
        <source>Ctrl+A</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="510"/>
        <source>De&amp;select All</source>
        <translation>取消选择 (&amp;S)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="513"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="518"/>
        <source>Pr&amp;eferences</source>
        <translation>偏好设置(&amp;E)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="526"/>
        <source>&amp;Ascending</source>
        <translation>升序(&amp;A)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="538"/>
        <source>&amp;Descending</source>
        <translation>降序(&amp;D)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="550"/>
        <source>&amp;By File Name</source>
        <translation>以文件名( &amp;B)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="558"/>
        <source>By &amp;Modification Time</source>
        <translation>以修改时间 (&amp;M)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="566"/>
        <source>By C&amp;reation Time</source>
        <translation>以创建时间(&amp;R)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="574"/>
        <source>By Deletio&amp;n Time</source>
        <translation>按删除时间</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="582"/>
        <source>By File &amp;Type</source>
        <translation>以文件类型 (&amp;T)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="590"/>
        <source>By &amp;Owner</source>
        <translation>按所有者(&amp;O)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="598"/>
        <source>By &amp;Group</source>
        <translation>按组(&amp;G)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="606"/>
        <source>&amp;Folder First</source>
        <translation>文件夹优先(&amp;F)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="614"/>
        <source>&amp;Hidden Last</source>
        <translation>隐藏文件次后(&amp;H)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="927"/>
        <source>Shift+F2</source>
        <translation>Shift+F2</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="1015"/>
        <source>Preserve Settings Recursively from &amp;Here</source>
        <translation>保留从此处重复设置(&amp;H)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="1020"/>
        <source>&amp;Go to Source of Inherited Settings</source>
        <translation>（&amp;G）转到继承设置源</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="1025"/>
        <source>&amp;Remove Settings of Nonexistent Folders</source>
        <translation>（&amp;R）删除不存在文件夹的设置</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="1033"/>
        <source>&amp;Clear</source>
        <translation>清除(&amp;C)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="667"/>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="728"/>
        <source>&amp;Case Sensitive</source>
        <translation>区分大小写(&amp;C)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="736"/>
        <source>By File &amp;Size</source>
        <translation>以文件大小 (&amp;S)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="745"/>
        <source>&amp;Close Window</source>
        <translation>关闭窗口(&amp;C)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="748"/>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="770"/>
        <source>Open Tab in &amp;Root Instance</source>
        <translation>在根实例中打开选项卡(&amp;T)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="784"/>
        <source>&amp;Folder</source>
        <translation>文件夹(&amp;F)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="796"/>
        <source>&amp;Blank File</source>
        <translation>空文件(&amp;B)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="887"/>
        <source>Preserve Settings for &amp;This Folder</source>
        <translation>为这个文件夹保存设置（&amp;T）</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="932"/>
        <source>&amp;Show/Focus Filter Bar</source>
        <translation>显示/聚焦过滤条(S)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="935"/>
        <source>Show Filter Bar</source>
        <translation>显示过滤条</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="938"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="946"/>
        <source>S&amp;plit View</source>
        <translation>分屏浏览(S)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="949"/>
        <source>Split View</source>
        <translation>分屏浏览</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="952"/>
        <source>F6</source>
        <translation>F6</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="957"/>
        <source>&amp;Copy Full Path</source>
        <translation>复制完整路径(C)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="964"/>
        <source>Ctrl+Shift+C</source>
        <translation>Ctrl+Shift+C</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="975"/>
        <source>Show Thumb&amp;nails</source>
        <translation>显示缩略图(&amp;N)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="978"/>
        <source>Show Thumbnails</source>
        <translation>显示缩略图</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="986"/>
        <source>S&amp;ide Pane</source>
        <translation>侧边栏(&amp;I)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="989"/>
        <source>F9</source>
        <translation>F9</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="994"/>
        <source>Hidden &amp;Shortcuts</source>
        <translation>隐藏快捷键（&amp;S）</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="999"/>
        <source>Open Tab in &amp;Admin Mode</source>
        <translation>在管理员模式中打开选项卡&amp;(A)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="1004"/>
        <location filename="../main-win.ui" line="1007"/>
        <source>Create Launcher</source>
        <translation>创建启动器</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="822"/>
        <source>Ctrl+B</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="827"/>
        <source>&amp;Clear All Filters</source>
        <translation>清除所有过滤(C)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="830"/>
        <source>Ctrl+Shift+K</source>
        <translation>Ctrl+Shift+K</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="839"/>
        <source>Close &amp;previous tabs</source>
        <translation>关闭上一个标签页(&amp;P)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="848"/>
        <source>Close &amp;next tabs</source>
        <translation>关闭下一个标签页(&amp;N)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="896"/>
        <source>Connect to &amp;Server</source>
        <translation>连接至服务器(&amp;S)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="904"/>
        <source>&amp;Location</source>
        <translation>位置(&amp;L)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="912"/>
        <source>&amp;Path Buttons</source>
        <translation>路径按钮(&amp;P)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="917"/>
        <source>&amp;Bulk Rename</source>
        <translation>批量重命名(&amp;B)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="924"/>
        <source>Bulk Rename</source>
        <translation>批量重命名</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="853"/>
        <source>Close &amp;other tabs</source>
        <translation>关闭其他标签页(&amp;O)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="819"/>
        <source>Permanent &amp;filter bar</source>
        <translation>永久过滤器栏(F)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="861"/>
        <source>&amp;Menu bar</source>
        <translation>菜单栏(&amp;M)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="864"/>
        <source>Menu bar</source>
        <translation>菜单栏</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="867"/>
        <source>Ctrl+M</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="876"/>
        <location filename="../main-win.ui" line="879"/>
        <source>Menu</source>
        <translation>菜单</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="623"/>
        <source>New &amp;Tab</source>
        <translation>新建标签页(&amp;T)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="164"/>
        <source>&amp;Customized View Settings</source>
        <translation>（&amp;C）自定义视图设置</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="626"/>
        <source>New Tab</source>
        <translation>新建标签页</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="629"/>
        <source>Ctrl+T</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="638"/>
        <source>Go &amp;Back</source>
        <translation>后退(&amp;B)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="641"/>
        <source>Go Back</source>
        <translation>后退</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="644"/>
        <source>Alt+Left</source>
        <translation>Alt+Left</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="653"/>
        <source>Go &amp;Forward</source>
        <translation>前进(&amp;F)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="656"/>
        <source>Go Forward</source>
        <translation>前进</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="659"/>
        <source>Alt+Right</source>
        <translation>Alt+右</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="664"/>
        <source>&amp;Invert Selection</source>
        <translation>反选(&amp;I)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="676"/>
        <source>&amp;Delete</source>
        <translation>删除(&amp;D)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="679"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="684"/>
        <source>&amp;Rename</source>
        <translation>重命名(&amp;R)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="691"/>
        <source>F2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="700"/>
        <source>C&amp;lose Tab</source>
        <translation>关闭标签页(&amp;L)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="703"/>
        <source>Ctrl+W</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="712"/>
        <source>File &amp;Properties</source>
        <translation>文件属性(&amp;P)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="715"/>
        <source>Alt+Return</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="720"/>
        <source>&amp;Folder Properties</source>
        <translation>文件夹属性(&amp;F)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="753"/>
        <source>Edit Bookmarks</source>
        <translation>编辑书签</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="762"/>
        <source>Open &amp;Terminal</source>
        <translation>打开终端(&amp;T)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="765"/>
        <source>F4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="775"/>
        <source>&amp;Edit Bookmarks</source>
        <translation>编辑书签(&amp;E)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="787"/>
        <source>Ctrl+Shift+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="799"/>
        <source>Ctrl+Alt+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="804"/>
        <source>&amp;Find Files</source>
        <translation>查找文件(&amp;F)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="811"/>
        <source>F3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="70"/>
        <source>&amp;File</source>
        <translation>文件(&amp;F)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="74"/>
        <source>C&amp;reate New</source>
        <translation>新建(&amp;C)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="102"/>
        <source>&amp;Help</source>
        <translation>帮助(&amp;H)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="109"/>
        <location filename="../main-win.ui" line="133"/>
        <source>&amp;View</source>
        <translation>查看(&amp;V)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="113"/>
        <source>&amp;Sorting</source>
        <translation>排序(&amp;S)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="189"/>
        <source>&amp;Edit</source>
        <translation>编辑(&amp;E)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="208"/>
        <source>&amp;Bookmarks</source>
        <translation>书签(&amp;B)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="215"/>
        <source>&amp;Go</source>
        <translation>转到(&amp;G)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="257"/>
        <source>Main Toolbar</source>
        <translation>主工具栏</translation>
    </message>
</context>
<context>
    <name>PCManFM::Application</name>
    <message>
        <location filename="../application.cpp" line="189"/>
        <source>Name of configuration profile</source>
        <translation>配置文件名称</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="189"/>
        <source>PROFILE</source>
        <translation>配置文件</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="192"/>
        <source>Run PCManFM-Qt as a daemon</source>
        <translation>以 Daemon 模式运行 PCManFM-Qt</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="195"/>
        <source>Quit PCManFM-Qt</source>
        <translation>退出 PCManFM-Qt</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="198"/>
        <source>Launch desktop manager</source>
        <translation>运行桌面管理器</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="201"/>
        <source>Turn off desktop manager if it&apos;s running</source>
        <translation>如桌面管理器正在运行，请关闭</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="204"/>
        <source>Open desktop preference dialog on the page with the specified name</source>
        <translation>在此页面上以指定名称打开桌面偏好设定对话框</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="204"/>
        <location filename="../application.cpp" line="219"/>
        <source>NAME</source>
        <translation>名称</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="207"/>
        <source>Open new window</source>
        <translation>打开新窗口</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="210"/>
        <source>Open Find Files utility</source>
        <translation>打开文件搜索实用程序</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="213"/>
        <source>Set desktop wallpaper from image FILE</source>
        <translation>从图像文件设置桌面墙纸</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="213"/>
        <source>FILE</source>
        <translation>文件</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="216"/>
        <source>MODE</source>
        <translation>模式</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="216"/>
        <source>Set mode of desktop wallpaper. MODE=(%1)</source>
        <translation>设置桌面墙纸的布局模式 模式=(%1)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="219"/>
        <source>Open Preferences dialog on the page with the specified name</source>
        <translation>在此页面上以指定名称打开偏好设定对话框</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="222"/>
        <source>Files or directories to open</source>
        <translation>要打开的文件或目录</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="222"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[文件1, 文件2,...]</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="660"/>
        <location filename="../application.cpp" line="665"/>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="665"/>
        <source>Terminal emulator is not set.</source>
        <translation>终端模拟器未设置。</translation>
    </message>
</context>
<context>
    <name>PCManFM::AutoRunDialog</name>
    <message>
        <location filename="../autorundialog.cpp" line="44"/>
        <source>Open in file manager</source>
        <translation>在文件管理器中打开</translation>
    </message>
    <message>
        <location filename="../autorundialog.cpp" line="137"/>
        <source>Removable Disk</source>
        <translation>可移动磁盘</translation>
    </message>
</context>
<context>
    <name>PCManFM::ConnectServerDialog</name>
    <message>
        <location filename="../connectserverdialog.cpp" line="9"/>
        <source>SSH</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="10"/>
        <source>FTP</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="11"/>
        <source>WebDav</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="12"/>
        <source>Secure WebDav</source>
        <translation>安全 WebDav</translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="13"/>
        <source>HTTP</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="14"/>
        <source>HTTPS</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopEntryDialog</name>
    <message>
        <location filename="../desktopentrydialog.cpp" line="35"/>
        <source>Command:</source>
        <translation>命令：</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="36"/>
        <source>The command to execute.</source>
        <translation>需要执行的命令.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="39"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="40"/>
        <source>The URL to access.</source>
        <translation>要访问的URL.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="67"/>
        <source>Select an icon</source>
        <translation>选择一个图标</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="69"/>
        <source>Images (*.png *.xpm *.svg *.svgz )</source>
        <translation>图像 (*.png *.xpm *.svg *.svgz )</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="91"/>
        <source>Select an executable file</source>
        <translation>选择一个可执行文件</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="99"/>
        <source>Select a file</source>
        <translation>选择一个文件</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopPreferencesDialog</name>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="55"/>
        <source>Fill with background color only</source>
        <translation>仅以背景色填充</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="56"/>
        <source>Stretch to fill the entire screen</source>
        <translation>拉伸图像以填充整个屏幕</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="57"/>
        <source>Stretch to fit the screen</source>
        <translation>拉伸图像以适合屏幕</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="58"/>
        <source>Center on the screen</source>
        <translation>在屏幕上居中</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="59"/>
        <source>Tile the image to fill the entire screen</source>
        <translation>平铺图像以填充整个屏幕</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="60"/>
        <source>Zoom the image to fill the entire screen</source>
        <translation>缩放图像以填充整个屏幕</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="272"/>
        <source>Select Wallpaper</source>
        <translation>选择壁纸</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="276"/>
        <source>Image Files</source>
        <translation>图像文件</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="318"/>
        <source>Select Wallpaper Folder</source>
        <translation>选择壁纸文件夹</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopWindow</name>
    <message>
        <location filename="../desktopwindow.cpp" line="333"/>
        <source>Trash (One item)</source>
        <translation>回收站( 1 个项目)</translation>
    </message>
    <message numerus="yes">
        <location filename="../desktopwindow.cpp" line="336"/>
        <source>Trash (%Ln items)</source>
        <translation>
            <numerusform>回收站( %Ln 个项目)</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="340"/>
        <source>Trash (Empty)</source>
        <translation>回收站(空)</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="375"/>
        <source>Computer</source>
        <translation>计算机</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="389"/>
        <source>Network</source>
        <translation>网络</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1052"/>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1058"/>
        <location filename="../desktopwindow.cpp" line="1098"/>
        <source>Stic&amp;k to Current Position</source>
        <translation>固定至当前位置(&amp;K)</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1066"/>
        <source>Empty Trash</source>
        <translation>清空回收站</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1132"/>
        <source>Hide Desktop Items</source>
        <translation>隐藏桌面项目</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1138"/>
        <source>Create Launcher</source>
        <translation>创建启动器</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1141"/>
        <source>Desktop Preferences</source>
        <translation>桌面偏好设置</translation>
    </message>
</context>
<context>
    <name>PCManFM::FilterBar</name>
    <message>
        <location filename="../tabpage.cpp" line="95"/>
        <source>Filter:</source>
        <translation>过滤器：</translation>
    </message>
</context>
<context>
    <name>PCManFM::FilterEdit</name>
    <message>
        <location filename="../tabpage.cpp" line="65"/>
        <source>Clear text (Ctrl+K or Esc)</source>
        <translation>清除文字 (Ctrl+K 或 Esc)</translation>
    </message>
</context>
<context>
    <name>PCManFM::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="142"/>
        <source>Root Instance</source>
        <translation>您正在使用 Root 用户实例</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="776"/>
        <source>Hide menu bar</source>
        <translation>隐藏菜单栏</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="777"/>
        <source>This will hide the menu bar completely, use Ctrl+M to show it again.</source>
        <translation>这将完全隐藏菜单栏，请使用 Ctrl+M 以恢复显示。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1224"/>
        <source>Version: %1</source>
        <translation>版本: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="175"/>
        <location filename="../mainwindow.cpp" line="2193"/>
        <source>&amp;Move to Trash</source>
        <translation>移至回收站(&amp;M)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="175"/>
        <location filename="../mainwindow.cpp" line="2193"/>
        <source>&amp;Delete</source>
        <translation>删除(&amp;D)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2029"/>
        <source>Customized View Settings</source>
        <translation>自定义的视图设置</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2300"/>
        <location filename="../mainwindow.cpp" line="2308"/>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2308"/>
        <source>Switch user command is not set.</source>
        <translation>切换用户命令尚未设置。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2399"/>
        <source>Cleaning Folder Settings</source>
        <translation>清除文件夹设置</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2400"/>
        <source>Do you want to remove settings of nonexistent folders?
They might be useful if those folders are created again.</source>
        <translation>是否要删除不存在的文件夹的设置? 如果再次创建这些文件夹，它们可能会很有用。</translation>
    </message>
</context>
<context>
    <name>PCManFM::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="215"/>
        <source>Icon View</source>
        <translation>图标视图</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="216"/>
        <source>Compact View</source>
        <translation>列表视图</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="217"/>
        <source>Thumbnail View</source>
        <translation>缩略图视图</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="218"/>
        <source>Detailed List View</source>
        <translation>详细信息视图</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="311"/>
        <source>Remove if added by user</source>
        <translation>如果由用户添加，则删除</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="335"/>
        <source>Open user-defined list</source>
        <translation>打开用户定义列表</translation>
    </message>
</context>
<context>
    <name>PCManFM::TabPage</name>
    <message>
        <location filename="../tabpage.cpp" line="452"/>
        <source>Search Results</source>
        <translation>搜索结果</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="455"/>
        <source>Applications</source>
        <translation>应用程序</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="459"/>
        <source>Computer</source>
        <translation>计算机</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="462"/>
        <source>Network</source>
        <translation>网络</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="465"/>
        <source>Trash</source>
        <translation>回收站</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="471"/>
        <source>Desktop</source>
        <translation>桌面</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="562"/>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="571"/>
        <source>Free space: %1 (Total: %2)</source>
        <translation>可用空间: %1 (总容量: %2)</translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="588"/>
        <source>%n item(s)</source>
        <translation>
            <numerusform>%n 个项目</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="590"/>
        <source> (%n hidden)</source>
        <translation>
            <numerusform> (%n 个隐藏)</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="595"/>
        <location filename="../tabpage.cpp" line="796"/>
        <location filename="../tabpage.cpp" line="810"/>
        <source>Link to</source>
        <translation>链接至</translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="822"/>
        <source>%n item(s) selected</source>
        <translation>
            <numerusform>已选中 %n 个项目</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PCManFM::View</name>
    <message>
        <location filename="../view.cpp" line="59"/>
        <source>Many files</source>
        <translation>许多文件</translation>
    </message>
    <message numerus="yes">
        <location filename="../view.cpp" line="60"/>
        <source>Do you want to open these %1 files?</source>
        <translation>
            <numerusform>你想要打开这些 %1 文件吗？</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../view.cpp" line="133"/>
        <source>Open in New T&amp;ab</source>
        <translation>在新标签页中打开(&amp;A)</translation>
    </message>
    <message>
        <location filename="../view.cpp" line="137"/>
        <source>Open in New Win&amp;dow</source>
        <translation>在新窗口中打开(&amp;D)</translation>
    </message>
    <message>
        <location filename="../view.cpp" line="145"/>
        <location filename="../view.cpp" line="174"/>
        <source>Open in Termina&amp;l</source>
        <translation>在终端中打开(&amp;L)</translation>
    </message>
    <message>
        <location filename="../view.cpp" line="160"/>
        <source>Show in New T&amp;ab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../view.cpp" line="164"/>
        <source>Show in New Win&amp;dow</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferences.ui" line="14"/>
        <source>Preferences</source>
        <translation>偏好设置</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="45"/>
        <source>User Interface</source>
        <translation>用户界面</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="35"/>
        <source>Behavior</source>
        <translation>行为</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="50"/>
        <location filename="../preferences.ui" line="642"/>
        <source>Thumbnail</source>
        <translation>缩略图</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="55"/>
        <source>Volume</source>
        <translation>卷</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="60"/>
        <source>Advanced</source>
        <translation>高级</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="222"/>
        <source>Select newly created files</source>
        <translation>选择新创建的文件</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="296"/>
        <source>Icons</source>
        <translation>图标</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="328"/>
        <source>Size of big icons:</source>
        <translation>大图标尺寸:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="345"/>
        <source>Size of small icons:</source>
        <translation>小图标尺寸:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="362"/>
        <source>Size of thumbnails:</source>
        <translation>缩略图大小:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="376"/>
        <source>Size of side pane icons:</source>
        <translation>侧边栏图标尺寸:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="308"/>
        <source>Icon theme:</source>
        <translation>图标主题:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="546"/>
        <source>Window</source>
        <translation>窗口</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="559"/>
        <source>Always show the tab bar</source>
        <translation>总是显示标签栏</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="566"/>
        <source>Show &apos;Close&apos; buttons on tabs	</source>
        <translation>在标签上显示“关闭”按钮	</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="580"/>
        <source>Remember the size of the last closed window</source>
        <translation>记住最后关闭的窗口的大小</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="587"/>
        <source>Default width of new windows:</source>
        <translation>新窗口的默认宽度:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="601"/>
        <source>Default height of new windows:</source>
        <translation>新窗口的默认高度:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="81"/>
        <source>Browsing</source>
        <translation>浏览</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="93"/>
        <source>Open files with single click</source>
        <translation>单击打开文件</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="162"/>
        <source>Default view mode:</source>
        <translation>默认视图:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="119"/>
        <source> sec</source>
        <translation> 秒</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="175"/>
        <source>File Operations</source>
        <translation>文件操作</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="181"/>
        <source>Confirm before deleting files</source>
        <translation>删除文件前确认</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="188"/>
        <source>Move deleted files to &quot;trash bin&quot; instead of erasing from disk.</source>
        <translation>将要删除的文件移至“回收站”，而不直接从磁盘中删除。</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="651"/>
        <source>Show thumbnails of files</source>
        <translation>显示文件缩略图</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="658"/>
        <source>Only show thumbnails for local files</source>
        <translation>仅显示本地文件的缩略图</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="40"/>
        <source>Display</source>
        <translation>显示</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="90"/>
        <source>If this is unchecked, the DE setting will be used.</source>
        <translation>如果取消这里的勾选，将会使用桌面环境的设置。</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="103"/>
        <location filename="../preferences.ui" line="116"/>
        <source>Set to zero to disable auto-selection.</source>
        <translation>设置为零以禁用自动选择。</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="106"/>
        <source>Delay of auto-selection in single click mode:</source>
        <translation>单击模式下自动选择的延迟：</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="144"/>
        <source>Open in current tab</source>
        <translation>在当前标签页中打开</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="149"/>
        <source>Open in new tab</source>
        <translation>在新标签页中打开</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="154"/>
        <source>Open in new window</source>
        <translation>在新窗口中打开</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="195"/>
        <source>Erase files on removable media instead of &quot;trash can&quot; creation</source>
        <translation>直接删除可移动媒体内的文件，而不移至回收站</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="202"/>
        <source>Confirm before moving files into &quot;trash can&quot;</source>
        <translation>移至回收站前确认</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="209"/>
        <location filename="../preferences.ui" line="409"/>
        <location filename="../preferences.ui" line="419"/>
        <source>Requires application restart to take effect completely</source>
        <translation>应用程序需重新启动才能完全生效</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="212"/>
        <source>Launch executable files without prompt</source>
        <translation>启动可执行文件时不提示</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="219"/>
        <source>Renamed files will also be selected</source>
        <translation>重命名的文件也会被选中</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="244"/>
        <source>Number of recent files:</source>
        <translation>最近的文件数：</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="325"/>
        <location filename="../preferences.ui" line="335"/>
        <source>Used by Icon View</source>
        <translation>使用图标视图</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="342"/>
        <location filename="../preferences.ui" line="352"/>
        <source>Used by Compact View and Detailed List View</source>
        <translation>使用列表与详细信息视图</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="359"/>
        <location filename="../preferences.ui" line="369"/>
        <source>Used by Thumbnail View</source>
        <translation>使用缩略图视图</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="389"/>
        <source>User interface</source>
        <translation>用户界面</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="402"/>
        <source>Treat backup files as hidden</source>
        <translation>将备份文件视作隐藏</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="422"/>
        <source>Show icons of hidden files shadowed</source>
        <translation>显示投影的隐藏文件的图标</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="459"/>
        <source>Minimum item margins in icon view:</source>
        <translation>图标视图最小项目外边距:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="466"/>
        <source>3 px by default.</source>
        <translation>默认为3px。</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="469"/>
        <location filename="../preferences.ui" line="493"/>
        <source> px</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="482"/>
        <source>x</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="489"/>
        <source>3 px by default.
A space is also reserved for 3 lines of text.</source>
        <translation>默认为3px。
会保留三行文字高度的空间。</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="506"/>
        <source>Lock</source>
        <translation>锁定</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="555"/>
        <source>When unchecked, the tab bar will be shown
only if there are more than one tab.</source>
        <translation>如不勾选，则标签栏仅会在有多于一个标签页时显示。</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="573"/>
        <source>Switch to newly opened tab</source>
        <translation>切换到新打开的标签页</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="615"/>
        <source>Reopen last window tabs in a new window</source>
        <translation>在新窗口中重新打开最后一个标签页</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="665"/>
        <location filename="../preferences.ui" line="677"/>
        <source>The built-in thumbnailer makes thumbnails of images that are supported by Qt.

Usually, most image types are supported. The default size limit is 4 MiB.</source>
        <translation>内置的缩略图器可制作Qt支持的图像的缩略图。

通常，支持大多数图像类型。默认大小限制为4 MiB。</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="670"/>
        <source>Image size limit for built-in thumbnailer:</source>
        <translation>内置缩略图的图像大小限制：</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="682"/>
        <location filename="../preferences.ui" line="718"/>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="698"/>
        <location filename="../preferences.ui" line="710"/>
        <source>If existing, external thumbnailers are used for videos, PDF documents, etc.

A value of -1 means that there is no limit for the file size (the default).</source>
        <translation>如果存在，则外部缩略图会用于视频，PDF文档等。

值-1表示文件大小没有限制（默认值）。</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="703"/>
        <source>File size limit for external thumbnailers:</source>
        <translation>外部缩略图的文件大小限制：</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="715"/>
        <source>No limit</source>
        <translation>不限制</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="833"/>
        <source>Terminal emulator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="842"/>
        <source>Command:</source>
        <translation type="unfinished">命令：</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="849"/>
        <source>Example: qterminal
It is the name of the executable file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="860"/>
        <source>Execution option:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="867"/>
        <source>Example: -e
It can be left empty if the terminal is already supported
or does not have such an option; required otherwise.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="879"/>
        <source>Custom option(s):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="886"/>
        <source>This is optional, depends on the terminal,
and can be any group of custom options.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="964"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="979"/>
        <source>Maximum search history:</source>
        <translation>搜索历史上限:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="993"/>
        <source>Clear search history</source>
        <translation>清除搜索记录</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="1028"/>
        <source>Application restart is needed for changes to take effect.</source>
        <translation>应用程序需要重新启动以使更改生效。</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="136"/>
        <source>Bookmarks menu:</source>
        <translation>书签菜单：</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="129"/>
        <source>Show folder context menu with Ctrl + right click</source>
        <translation>使用Ctrl + 鼠标右键显示文件夹上下文菜单</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="229"/>
        <source>Open folders in new tabs as far as possible</source>
        <translation>尽可能在新标签页中打开文件夹</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="232"/>
        <source>Single window mode</source>
        <translation>单窗口模式</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="412"/>
        <source>Always show real file names</source>
        <translation>总是显示真实文件名</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="429"/>
        <source>Do not show file tooltips</source>
        <translation>不要显示文件信息提示</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="436"/>
        <source>Disable smooth scrolling</source>
        <translation>禁用平滑滚动</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="648"/>
        <source>Needs ffmpegthumbnailer</source>
        <translation>需要 ffmpegthumbnailer</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="754"/>
        <source>Auto Mount</source>
        <translation>自动挂载</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="760"/>
        <source>Mount mountable volumes automatically on program startup</source>
        <translation>程序启动时自动挂载可挂载的卷</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="767"/>
        <source>Mount removable media automatically when they are inserted</source>
        <translation>插入可移动媒体时自动挂载</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="774"/>
        <source>Show available options for removable media when they are inserted</source>
        <translation>在可移动媒体插入时显示可用选项</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="784"/>
        <source>When removable medium unmounted:</source>
        <translation>卸载可移动媒体时:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="790"/>
        <source>Close &amp;tab containing removable medium</source>
        <translation>关闭包含可移动媒体的标签页(&amp;T)</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="797"/>
        <source>Chan&amp;ge folder in the tab to home folder</source>
        <translation>将标签页内容更改为主文件夹(&amp;G)</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="824"/>
        <source>Programs</source>
        <translation>程序</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="900"/>
        <source>Switch &amp;user command:</source>
        <translation>切换用户命令(&amp;U):</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="910"/>
        <source>Example:
lxsudo dbus-run-session -- %s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="918"/>
        <source>Archiver in&amp;tegration:</source>
        <translation>默认压缩程序(&amp;T):</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="934"/>
        <source>Templates</source>
        <translation>模板</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="940"/>
        <source>Show only user defined templates in menu</source>
        <translation>仅在菜单中显示用户定义的模板</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="947"/>
        <source>Show only one template for each MIME type</source>
        <translation>仅为每个 MIME 类型显示一个模板</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="954"/>
        <source>Run default application after creation from template</source>
        <translation>创建文件模板后运行默认应用程序</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="395"/>
        <source>Use SI decimal prefixes instead of IEC binary prefixes</source>
        <translation>使用国际单位制的十进制词头，而不使用IEC的二进制词头</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bulkrename.cpp" line="185"/>
        <location filename="../bulkrename.cpp" line="247"/>
        <location filename="../bulkrename.cpp" line="288"/>
        <source>Renaming files...</source>
        <translation>重命名文件...</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="185"/>
        <location filename="../bulkrename.cpp" line="247"/>
        <location filename="../bulkrename.cpp" line="288"/>
        <source>Abort</source>
        <translation>忽略</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="194"/>
        <location filename="../bulkrename.cpp" line="254"/>
        <location filename="../bulkrename.cpp" line="295"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="194"/>
        <location filename="../bulkrename.cpp" line="254"/>
        <location filename="../bulkrename.cpp" line="295"/>
        <source>Renaming is aborted.</source>
        <translation>重命名已取消。</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="220"/>
        <location filename="../bulkrename.cpp" line="224"/>
        <location filename="../bulkrename.cpp" line="234"/>
        <location filename="../bulkrename.cpp" line="243"/>
        <location filename="../bulkrename.cpp" line="277"/>
        <location filename="../bulkrename.cpp" line="281"/>
        <location filename="../bulkrename.cpp" line="318"/>
        <location filename="../bulkrename.cpp" line="322"/>
        <location filename="../tabpage.cpp" line="1149"/>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="220"/>
        <location filename="../bulkrename.cpp" line="277"/>
        <location filename="../bulkrename.cpp" line="318"/>
        <source>No file could be renamed.</source>
        <translation>没有文件可以被重命名。</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="224"/>
        <location filename="../bulkrename.cpp" line="281"/>
        <location filename="../bulkrename.cpp" line="322"/>
        <source>Some files could not be renamed.</source>
        <translation>某些文件不能被重命名。</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="234"/>
        <source>Nothing to find.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="243"/>
        <source>Invalid regular expression.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="1149"/>
        <source>Cannot open as Admin.</source>
        <translation>无法以管理员身份打开。</translation>
    </message>
</context>
</TS>
